Section3Payload

Struct Section3Payload 

pub struct Section3Payload {
    pub grid_def_source: u8,
    pub num_points: u32,
    pub num_point_list_octets: u8,
    pub point_list_interpretation: u8,
    pub template_num: u16,
    pub template: GridDefinitionTemplate,
}

Fields

grid_def_source: u8

Source of grid definition (see Code table 3.0 and Note 1).

num_points: u32

Number of data points.

num_point_list_octets: u8

Number of octets for optional list of numbers (see Note 2).

point_list_interpretation: u8

Interpretation of list of numbers (see Code table 3.11).

template_num: u16

Grid definition template number (= N) (see Code table 3.1).

template: GridDefinitionTemplate

Grid Definition Template (see Template 3.N, where N is the Grid Definition Template Number given in octets 13-14).